@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 4430 2011-11-08 06:01:32Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 4471 2011-11-26 10:19:40Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -163,10 +163,8 @@ class ScriptLibInfo
 	
 	// スマートフォン用jQueryファイル
 	const JQUERYS_FILENAME			= 'jquery-1.5.2.min.js';					// JQuery
-//	const JQUERYS_MOBILE_FILENAME	= 'jquery_mobile/jquery.mobile-1.0a4.1.min.js';					// JQuery Mobile
-//	const JQUERYS_MOBILE_CSS		= 'jquery_mobile/jquery.mobile-1.0a4.1.min.css';				// JQuery Mobile
-	const JQUERYS_MOBILE_FILENAME	= 'jquery_mobile/jquery.mobile-1.0rc1.min.js';					// JQuery Mobile
-	const JQUERYS_MOBILE_CSS		= 'jquery_mobile/jquery.mobile-1.0rc1.min.css';				// JQuery Mobile
+	const JQUERYS_MOBILE_FILENAME	= 'jquery_mobile/jquery.mobile-1.0.min.js';					// JQuery Mobile
+	const JQUERYS_MOBILE_CSS		= 'jquery_mobile/jquery.mobile-1.0.min.css';				// JQuery Mobile
 	
 	/**
 	 * コンストラクタ
