@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 4297 2011-09-06 03:00:32Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 4348 2011-09-24 12:03:23Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -66,6 +66,64 @@ class BaseWidgetContainer extends Core
 		
 		// URLパラメータ並び順
 		$this->urlParamOrder = array(
+			// コンテンツID
+			M3_REQUEST_PARAM_CONTENT_ID				=> -20,		// 汎用コンテンツID
+			M3_REQUEST_PARAM_CONTENT_ID_SHORT		=> -19,		// 汎用コンテンツID(略式)
+			M3_REQUEST_PARAM_PRODUCT_ID				=> -18,		// 製品ID
+			M3_REQUEST_PARAM_PRODUCT_ID_SHORT		=> -17,		// 製品ID(略式)
+			M3_REQUEST_PARAM_BLOG_ID				=> -16,		// ブログID
+			M3_REQUEST_PARAM_BLOG_ID_SHORT			=> -15,		// ブログID(略式)
+			M3_REQUEST_PARAM_BLOG_ENTRY_ID			=> -14,		// ブログ記事ID
+			M3_REQUEST_PARAM_BLOG_ENTRY_ID_SHORT	=> -13,		// ブログ記事ID(略式)
+			M3_REQUEST_PARAM_BBS_ID					=> -12,		// 掲示板投稿記事ID
+			M3_REQUEST_PARAM_BBS_ID_SHORT			=> -11,		// 掲示板投稿記事ID(略式)
+			M3_REQUEST_PARAM_BBS_THREAD_ID			=> -10,		// 掲示板投稿スレッドID
+			M3_REQUEST_PARAM_BBS_THREAD_ID_SHORT	=> -9,		// 掲示板投稿スレッドID(略式)
+			M3_REQUEST_PARAM_USER_ID				=> -8,		// ユーザ作成コンテンツID
+			M3_REQUEST_PARAM_USER_ID_SHORT			=> -7,		// ユーザ作成コンテンツID(略式)
+			M3_REQUEST_PARAM_ROOM_ID				=> -6,		// ユーザ作成コンテンツ区画ID
+			M3_REQUEST_PARAM_ROOM_ID_SHORT			=> -5,		// ユーザ作成コンテンツ区画ID(略式)
+			M3_REQUEST_PARAM_EVENT_ID				=> -4,		// イベントID
+			M3_REQUEST_PARAM_EVENT_ID_SHORT			=> -3,		// イベントID(略式)
+			M3_REQUEST_PARAM_PHOTO_ID				=> -2,		// 画像ID
+			M3_REQUEST_PARAM_PHOTO_ID_SHORT			=> -1,		// 画像ID(略式)
+			// URLパラメータ
+			M3_REQUEST_PARAM_PAGE_SUB_ID			=> 1,		// ページサブID
+			M3_REQUEST_PARAM_PAGE_CONTENT_ID		=> 2,		// ページコンテンツID
+			M3_REQUEST_PARAM_WIDGET_ID 				=> 3,		// ウィジェットID
+			M3_REQUEST_PARAM_TEMPLATE_ID			=> 4,		// テンプレートID
+			M3_REQUEST_PARAM_URL					=> 5,		// リンク先等のURL
+			M3_REQUEST_PARAM_STAMP					=> 6,		// 公開発行ID
+			M3_REQUEST_PARAM_OPTION					=> 7,		// 通信オプション
+			M3_REQUEST_PARAM_OPERATION_COMMAND		=> 8,		// 実行処理
+			M3_REQUEST_PARAM_OPERATION_WIKI_COMMAND	=> 9,		// Wikiコマンド実行
+			M3_REQUEST_PARAM_OPERATION_TASK			=> 10,		// ウィジェット間共通処理
+			M3_REQUEST_PARAM_OPERATION_ACT			=> 11,		// クライアントからの実行処理
+			M3_REQUEST_PARAM_OPERATION_LANG			=> 12,		// 言語指定表示
+			M3_REQUEST_PARAM_SERIAL_NO				=> 13,		// シリアル番号
+			M3_REQUEST_PARAM_PAGE_NO      			=> 14,		// ページ番号
+			M3_REQUEST_PARAM_LIST_NO				=> 15,		// 一覧番号
+			M3_REQUEST_PARAM_ITEM_NO	      		=> 16,		// 項目番号
+			M3_REQUEST_PARAM_OPERATION_TODO			=> 17,		// 指定ウィジェットに実行させる処理
+			M3_REQUEST_PARAM_FROM					=> 18,		// メッセージの送信元ウィジェットID
+			M3_REQUEST_PARAM_VIEW_STYLE				=> 19,		// 表示スタイル
+			M3_REQUEST_PARAM_FORWARD				=> 20,		// 画面遷移用パラメータ
+			M3_REQUEST_PARAM_ADMIN_KEY				=> 21,		// 管理者一時キー
+			M3_REQUEST_PARAM_OPEN_BY				=> 22,		// ウィンドウの開き方
+			M3_REQUEST_PARAM_SHOW_HEADER			=> 23,		// ヘッダ部表示制御
+			M3_REQUEST_PARAM_SHOW_FOOTER			=> 24,		// フッタ部表示制御
+			M3_REQUEST_PARAM_SHOW_MENU				=> 25,		// メニュー部表示制御
+			M3_REQUEST_PARAM_KEYWORD				=> 26,		// 検索キーワード
+			M3_REQUEST_PARAM_HISTORY				=> 27,		// 履歴インデックスNo
+			M3_REQUEST_PARAM_DEF_PAGE_ID			=> 28,		// ページID(画面編集用)
+			M3_REQUEST_PARAM_DEF_PAGE_SUB_ID		=> 29,		// ページサブID(画面編集用)
+			M3_REQUEST_PARAM_PAGE_DEF_SERIAL		=> 30,		// ページ定義のレコードシリアル番号(設定画面起動時)
+			M3_REQUEST_PARAM_PAGE_DEF_CONFIG_ID		=> 31,		// ページ定義のウィジェット定義ID(設定画面起動時)
+			M3_REQUEST_PARAM_BACK_URL				=> 32,		// 戻り先URL
+			M3_REQUEST_PARAM_BACKUP_URL				=> 33,		// URL退避用(画面編集時)
+			M3_REQUEST_PARAM_SERVER					=> 34,		// サーバ指定
+			M3_REQUEST_PARAM_CATEGORY_ID			=> 35);		// カテゴリID(共通)
+/*		$this->urlParamOrder = array(
 			M3_REQUEST_PARAM_PAGE_SUB_ID			=> 1,		// ページサブID
 			M3_REQUEST_PARAM_PAGE_CONTENT_ID		=> 2,		// ページコンテンツID
 			M3_REQUEST_PARAM_WIDGET_ID 				=> 3,		// ウィジェットID
@@ -93,6 +151,7 @@ class BaseWidgetContainer extends Core
 			M3_REQUEST_PARAM_PAGE_DEF_CONFIG_ID		=> 25,		// ページ定義のウィジェット定義ID(設定画面起動時)
 			M3_REQUEST_PARAM_CONTENT_ID				=> 26,		// コンテンツID
 			M3_REQUEST_PARAM_CONTENT_ID_SHORT		=> 27);				// コンテンツID(略式)
+			*/
 		
 		// 階層化ページ
 		$this->_useHierPage = $this->gSystem->hierarchicalPage();
