@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: instanceManager.php 3630 2010-09-25 01:23:58Z fishbone $
+ * @version    SVN: $Id: instanceManager.php 4391 2011-10-12 12:24:35Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -39,7 +39,7 @@ class InstanceManager extends Core
 		$this->systemDb = new SystemDb();
 		
 		// 変数初期化
-		$this->addonArray = array();
+		//$this->addonArray = array();
 	}
 	/**
 	 * システムDBオブジェクトを取得
@@ -90,20 +90,35 @@ class InstanceManager extends Core
 	 */
 	public function getObject($id)
 	{
+		global $gEnvManager;
+				
+		// 追加クラス情報がないときは、追加クラス情報をロード
+		if (!isset($this->addonArray)) $this->loadAddonClassInfo();
+
 		$addonObj = $this->addonArray[$id];
-		if (!isset($addonObj)){			// 取得されていないとき
-			// アドオンをロード
-			$this->loadAddonClass();
-			$addonObj = $this->addonArray[$id];
+		if (isset($addonObj) && is_string($addonObj)){		// クラス名のとき
+			$loadClass = $addonObj;
+			
+			// クラスファイルパス
+			$loadClassFile = $gEnvManager->getAddonsPath() . '/' . $id . '/' . $loadClass . '.php';
+			
+			// ファイル読み込み
+			require_once($loadClassFile);
+		
+			// クラスオブジェクト格納
+			$addonObj = $this->addonArray[$id] = new $loadClass();
 		}
 		return $addonObj;
 	}
 	/**
-	 * 追加クラスをインスタンス化
+	 * 追加クラス情報を取得
 	 */
-	public function loadAddonClass()
+	public function loadAddonClassInfo()
 	{
 		global $gEnvManager;
+
+		// 追加クラス情報初期化
+		$this->addonArray = array();
 		
 		// DB接続不可のときは終了
 		if (!$gEnvManager->canUseDb()) return;
@@ -121,12 +136,15 @@ class InstanceManager extends Core
 				// クラスファイルパス
 				$loadClassFile = $this->addonDir . '/' . $addonId . '/' . $loadClass . '.php';
 		
+				// 追加クラスファイルがあるときは追加クラス情報を格納
 				if (file_exists($loadClassFile)){
+					$this->addonArray[$addonId] = $loadClass;
+
 					// ファイル読み込み
-					require_once($loadClassFile);
+//				require_once($loadClassFile);
 			
 					// クラス作成
-					$this->addonArray[$addonId] = new $loadClass();
+//					$this->addonArray[$addonId] = new $loadClass();
 				} else {
 					echo 'addon load error: id=' . $addonId;
 				}
