@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: _develop.sql 4460 2011-11-16 12:52:08Z fishbone $
+-- * @version    SVN: $Id: _develop.sql 4472 2011-11-26 11:00:36Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- [開発ウィジェット登録]   *****仕様変更あり注意*****
@@ -19,7 +19,7 @@
 DELETE FROM _widgets WHERE wd_id = 'photo_cart';
 INSERT INTO _widgets 
 (wd_id,        wd_name,                     wd_version, wd_author,      wd_copyright, wd_license,                wd_license_type, wd_official_level, wd_description, wd_has_admin, wd_initialized, wd_launch_index, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
-('photo_cart', 'フォトギャラリー - カート', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10,                'フォトギャラリーのカート内の商品を表示するオプションウィジェット。',   false,    true,           100, 0, 0, now(),      now());
+('photo_cart', 'フォトギャラリー - カート', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10,                'フォトギャラリーのカート内の商品を表示するオプションウィジェット。',   true,    true,           100, 0, 0, now(),      now());
 DELETE FROM _widgets WHERE wd_id = 'photo_shop';
 INSERT INTO _widgets
 (wd_id,     wd_name,              wd_version, wd_author,      wd_copyright, wd_license, wd_license_type, wd_official_level, wd_description,                                                        wd_has_admin, wd_initialized, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
@@ -103,3 +103,9 @@ INSERT INTO product_price
 (pp_product_class, pp_product_id, pp_product_type_id, pp_language_id, pp_price_type_id, pp_currency_id, pp_price) VALUES 
 ('photo',          0,             'download',         'ja',           'selling',        'JPY',          100),
 ('photo',          1,             'download',         'ja',           'selling',        'JPY',          200);
+
+-- 個人情報追加フィールド
+TRUNCATE TABLE person_info_opt_field;
+INSERT INTO person_info_opt_field
+(pf_id,    pf_language_id, pf_name,   pf_field_type, pf_index) VALUES
+('sports', 'ja',           'スポーツ', 'text',        1);
