@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: blog.sql 4012 2011-02-23 00:12:32Z fishbone $
+-- * @version    SVN: $Id: blog.sql 4143 2011-05-16 14:22:21Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- [ブログ標準管理メニュー]
@@ -28,11 +28,10 @@ INSERT INTO _nav_item
 (106,   100,          5,        'admin_menu', 'smenudef',                      '',          0,               '',       'メニュー管理', 'メニュー管理', 'メニュー定義を管理します。', true),
 (200,   0,            1,        'admin_menu', '_login',                       '',          0,               '',       'システム運用', '', '', true),
 (201,   200,          0,        'admin_menu', 'userlist',                     '',          0,               '',       'ユーザ一覧',   'ユーザ一覧', 'ログイン可能なユーザを管理します。', true),
-(202,   200,          1,        'admin_menu', 'loginstatus',                  '',          0,               '',       'ログイン状況', 'ログイン状況', 'ユーザのログイン状況を表示します。', true),
-(203,   200,          2,        'admin_menu', 'analyzecalc',                  '',          0,               '',       'アクセス解析', 'アクセス解析', 'サイトへのアクセス状況を表示します。', true),
-(204,   200,          3,        'admin_menu', 'opelog',                       '',          0,               '',       '運用ログ参照', '運用ログ参照', 'システムの運用状況を表示します。', true),
-(205,   200,          4,        'admin_menu', 'accesslog',                    '',          0,               '',       'アクセスログ参照', 'アクセスログ参照', 'サイトへのアクセス状況を表示します。', true),
-(206,   200,          5,        'admin_menu', 'searchwordlog',                '',          0,               '',       '検索語ログ参照', '検索語ログ参照', 'サイトで検索されたキーワードを表示します。', true),
+(202,   200,          1,        'admin_menu', 'analyzecalc',                  '',          0,               '',       'アクセス解析', 'アクセス解析', 'サイトへのアクセス状況を表示します。', true),
+(203,   200,          2,        'admin_menu', 'opelog',                       '',          0,               '',       '運用ログ参照', '運用ログ参照', 'システムの運用状況を表示します。', true),
+(204,   200,          3,        'admin_menu', 'accesslog',                    '',          0,               '',       'アクセスログ参照', 'アクセスログ参照', 'サイトへのアクセス状況を表示します。', true),
+(205,   200,          4,        'admin_menu', 'searchwordlog',                '',          0,               '',       '検索語ログ参照', '検索語ログ参照', 'サイトで検索されたキーワードを表示します。', true),
 (300,   0,            2,        'admin_menu', '_config',                      '',          0,               '',       'システム管理', '', '', true),
 (301,   300,          0,        'admin_menu', 'configsite',                   '',          0,               '',       '基本情報', '基本情報', 'サイト運営に必要な情報を設定します。', true),
 (302,   300,          1,        'admin_menu', 'configsys',                    '',          0,               '',       'システム情報', 'システム情報', 'システム全体の設定、運用状況を管理します。', true),
@@ -57,11 +56,10 @@ INSERT INTO _nav_item
 (10106,   10100,          5,        'admin_menu.en', 'smenudef',                      '',          0,               '',       'Menu Administration', 'Menu Administration', 'Administrate menu definition.', true),
 (10200,   0,            1,        'admin_menu.en', '_login',                       '',          0,               '',       'System Operation', '', '', true),
 (10201,   10200,          0,        'admin_menu.en', 'userlist',                     '',          0,               '',       'User List',   'User List', 'Administrate user to login.', true),
-(10202,   10200,          1,        'admin_menu.en', 'loginstatus',                  '',          0,               '',       'Login Status', 'Login Status', 'View user login status.', true),
-(10203,   10200,          2,        'admin_menu.en', 'analyzecalc',                  '',          0,               '',       'Access Analytics', 'Access Analytics', 'Analyze site access.', true),
-(10204,   10200,          3,        'admin_menu.en', 'opelog',                       '',          0,               '',       'Operation Log', 'Operation Log', 'View system operation log.', true),
-(10205,   10200,          4,        'admin_menu.en', 'accesslog',                    '',          0,               '',       'Access Log', 'Access Log', 'View site access log.', true),
-(10206,   10200,          5,        'admin_menu.en', 'searchwordlog',                '',          0,               '',       'Search Word Log', 'Search Word Log', 'View words to search.', true),
+(10202,   10200,          1,        'admin_menu.en', 'analyzecalc',                  '',          0,               '',       'Access Analytics', 'Access Analytics', 'Analyze site access.', true),
+(10203,   10200,          2,        'admin_menu.en', 'opelog',                       '',          0,               '',       'Operation Log', 'Operation Log', 'View system operation log.', true),
+(10204,   10200,          3,        'admin_menu.en', 'accesslog',                    '',          0,               '',       'Access Log', 'Access Log', 'View site access log.', true),
+(10205,   10200,          4,        'admin_menu.en', 'searchwordlog',                '',          0,               '',       'Search Word Log', 'Search Word Log', 'View words to search.', true),
 (10300,   0,            2,        'admin_menu.en', '_config',                      '',          0,               '',       'System Administration', '', '', true),
 (10301,   10300,          0,        'admin_menu.en', 'configsite',                   '',          0,               '',       'Site Information', 'Site Information', 'Configure site information.', true),
 (10302,   10300,          1,        'admin_menu.en', 'configsys',                    '',          0,               '',       'System Information', 'System Information', 'Configure sytem information.', true),
