@@ -9,7 +9,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3admin1.5.2.js 4001 2011-02-17 00:18:49Z fishbone $
+ * @version    SVN: $Id: m3admin1.5.3.js 4374 2011-10-05 00:27:10Z fishbone $
  * @link       http://www.magic3.org
  */
 // 親ウィンドウを更新
@@ -28,6 +28,13 @@ function m3UpdateParentWindowByConfig(serial)
 		if (window.opener.parent.m3UpdateByChildWindow) window.opener.parent.m3UpdateByChildWindow();
 	}
 }
+// 親ウィンドウサイズを調整
+function m3AdjustParentWindow()
+{
+	if (window.parent){
+		if (window.parent.m3AdjustWindow) window.parent.m3AdjustWindow();
+	}
+}
 // ウィンドウサイズ調整
 function m3AdjustHeight(obj, min)
 {
