@@ -16,9 +16,9 @@ defined('M3_SYSTEM') or die('Access error: Direct access denied.');
 <table width="100%" border="0" cellspacing="0" cellpadding="0">
   <tr>
 	<?php if (mosCountModules ('left')){ ?>
-    <td valign="top"><?php mosLoadModules('left'); ?></td>
+    <td style="vertical-align:top;"><?php mosLoadModules('left'); ?></td>
 	<?php } ?>
-    <td valign="top"><?php mosMainBody(); ?></td>
+    <td style="vertical-align:top;"><?php mosMainBody(); ?></td>
   </tr>
 </table>
 </body>
