@@ -8,15 +8,15 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installInputparamWidgetContainer.php 2363 2009-09-26 14:45:44Z fishbone $
+ * @version    SVN: $Id: _installInputparamWidgetContainer.php 3791 2010-11-08 07:07:17Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/_installBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/_installDb.php');
 
-class _installInputparamWidgetContainer extends BaseWidgetContainer
+class _installInputparamWidgetContainer extends _installBaseWidgetContainer
 {
 	/**
 	 * コンストラクタ
@@ -51,9 +51,6 @@ class _installInputparamWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gPageManager;
-		global $gEnvManager;
-		
 		// ########### 画面項目の表示制御 ############
 		// PostgreSQLのPDOが使用可能かどうか
 		$canUseDB = false;
@@ -71,7 +68,7 @@ class _installInputparamWidgetContainer extends BaseWidgetContainer
 		} else {
 			$this->tmpl->setAttribute("db_mysql", "visibility", "hidden");
 		}
-		if (!$canUseDB) $this->setMsg(self::MSG_USER_ERR, "DBが使用できません");
+		if (!$canUseDB) $this->setMsg(self::MSG_USER_ERR, $this->_('Can\'t use database.'));			// DBが使用できません
 		
 		$dbtype = '';
 		$isConfigured = false;		// 設定ファイルが作成されたかどうか
@@ -105,7 +102,7 @@ class _installInputparamWidgetContainer extends BaseWidgetContainer
 				$dbuser = $this->gConfig->getDbConnectUser();
 				$password = $this->gConfig->getDbConnectPassword();
 			} else {// 設定値がないときはデフォルト値を設定
-				$sytemRootUrl = $gEnvManager->calcSystemRootUrl();
+				$sytemRootUrl = $this->gEnv->calcSystemRootUrl();
 				if (empty($sytemRootUrl)) $sytemRootUrl = 'http://' . $_SERVER['SERVER_NAME'] . '/' . M3_SYSTEM_ROOT_DIR_NAME;
 				$rooturl = $sytemRootUrl;
 				$hostname = 'localhost';
@@ -121,15 +118,15 @@ class _installInputparamWidgetContainer extends BaseWidgetContainer
 			$hostname = $request->trimValueOf('hostname');
 			//$this->checkSingleByte($hostname, "ホスト名");// IPアドレスを入力したとき「.」が除かれる
 			$dbuser = $request->trimValueOf('dbuser');
-			$this->checkSingleByte($dbuser, "DBユーザ");
+			$this->checkSingleByte($dbuser, $this->_('User'));		// DBユーザ
 			$password = $request->trimValueOf('password');
 			$dbname = $request->trimValueOf('dbname');
-			$this->checkSingleByte($dbname, "DB名");
+			$this->checkSingleByte($dbname, $this->_('Database Name'));			// DB名
 			
 			// DB種別
 			$dbtype = $request->trimValueOf('dbtype');
 			if ($dbtype != M3_DB_TYPE_PGSQL && $dbtype != M3_DB_TYPE_MYSQL){		// DBが選択されていないとき
-				$this->setMsg(self::MSG_USER_ERR, "DB種別が設定されていません");
+				$this->setMsg(self::MSG_USER_ERR, $this->_('Database Type not selected.'));		// DB種別が設定されていません
 			}
 
 			if ($this->getMsgCount() == 0){// 入力チェックOKの場合
@@ -145,25 +142,25 @@ class _installInputparamWidgetContainer extends BaseWidgetContainer
 			
 					// 完了メッセージを出力
 					if ($ret){
-						$this->setMsg(self::MSG_GUIDANCE, "設定値を更新しました");
+						$this->setMsg(self::MSG_GUIDANCE, $this->_('Configration updated.'));		// 設定値を更新しました
 						$isConfigured = true;
 					} else {
 						$this->setMsg(self::MSG_APP_ERR, $msg);
-						$this->setMsg(self::MSG_APP_ERR, "設定値の更新に失敗しました");
+						$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in updating configration.'));		// 設定値の更新に失敗しました
 					}
 				} else if ($act == 'testdb'){		// DB接続テスト
 					$dsn = $dbtype . ':' . 'host=' . $hostname . ';dbname=' . $dbname;
 					$db = new _installDB();
 					if ($db->testDbConnection($dsn, $dbuser, $password)){
-						$msg = '<b><font color="green">接続正常</font></b>';
+						$msg = '<b><font color="green">' . $this->_('Succeeded in connecting database.') . '</font></b>';			// 接続正常
 						$msg .= ' => ';
 						if ($db->testDbTable($dsn, $dbuser, $password)){
-							$msg .= '<b><font color="green">テーブル作成正常</font></b>';
+							$msg .= '<b><font color="green">' . $this->_('Succeeded in creating table.') . '</font></b>';	// テーブル作成正常
 						} else {
-							$msg .= '<b><font color="red">テーブル作成エラー</font></b>';
+							$msg .= '<b><font color="red">' . $this->_('Failed in creating table.') . '</font></b>';			// テーブル作成エラー
 						}
 					} else {
-						$msg .= '<b><font color="red">接続エラー</font></b>';
+						$msg .= '<b><font color="red">' . $this->_('Failed in connecting database.') . '</font></b>';		// 接続エラー
 					}
 					$this->tmpl->addVar('_widget', 'db_test',	$msg);
 				}
@@ -183,6 +180,24 @@ class _installInputparamWidgetContainer extends BaseWidgetContainer
 		
 		// 設定ファイルの内容をみて、ボタンを制御
 		if (!$this->gConfig->isConfigured() && !$isConfigured) $this->tmpl->addVar('_widget', 'button_disabled', 'disabled');
+		
+		// テキストをローカライズ
+		$localeText = array();
+		$localeText['label_update_config'] = $this->_('Update Config');		// 設定値を更新
+		$localeText['label_test_connection'] = $this->_('Test Connection');// 接続テスト
+		$localeText['msg_change_config'] = $this->_('Configration changed.\\nUpdate configration?');// 設定値が変更されています\n設定値を保存しますか?
+		$localeText['msg_update_config'] = $this->_('Update configration?');//設定値を更新しますか?
+		$localeText['title_input_site_info'] = $this->_('Input Site Information');	// サイト情報入力
+		
+		$localeText['label_site_info'] = $this->_('Site Information');	// サイト情報
+		$localeText['label_root_url'] = $this->_('Root URL');	// ルートURL
+		$localeText['label_db_info'] = $this->_('Database Information');	// DB接続情報
+		$localeText['label_db_type'] = $this->_('Database Type');	// DB種別
+		$localeText['label_db_hostname'] = $this->_('Hostname');	// ホスト名
+		$localeText['label_db_name'] = $this->_('Database Name');	// DB名
+		$localeText['label_db_user'] = $this->_('User');	// DBユーザ
+		$localeText['label_db_password'] = $this->_('Password');	// パスワード
+		$this->setLocaleText($localeText);
 	}
 }
 ?>
