@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainOpelogWidgetContainer.php 4126 2011-05-10 12:01:56Z fishbone $
+ * @version    SVN: $Id: admin_mainOpelogWidgetContainer.php 4321 2011-09-14 22:20:49Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -185,6 +185,7 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 			$localeText['label_check'] = $this->_('Checked');		// 確認
 			$localeText['label_message'] = $this->_('Message');			// メッセージ
 			$localeText['label_message_detail'] = $this->_('Message Detail');// メッセージ詳細
+			$localeText['label_message_code'] = $this->_('Message Code');// メッセージコード
 			$localeText['label_access_log_no'] = $this->_('Access Log No');			// アクセスログ番号
 			$localeText['label_date'] = $this->_('Date');			// 日時
 			$localeText['label_update'] = $this->_('Update');	// 更新
@@ -366,6 +367,7 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 				$isMsgChecked = $row['ol_checked'];		// 確認済みかどうか
 				$logMsg = $row['ol_message'];		// メッセージ
 				$logMsgDetail = $row['ol_message_ext'];// メッセージ詳細
+				$logMsgCode = $row['ol_message_code'];// メッセージコード
 				$accessLog = '';// アクセスログシリアル番号
 				if (!empty($row['ol_access_log_serial'])) $accessLog = $this->convertToDispString($row['ol_access_log_serial']);
 				$time = $this->convertToDispDateTime($row['ol_dt']);	// 出力日時
@@ -380,6 +382,7 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "msg_checked", $isChecked);
 		$this->tmpl->addVar("_widget", "message", $this->convertToDispString($logMsg));
 		$this->tmpl->addVar("_widget", "detail", $this->convertToDispString($logMsgDetail));
+		$this->tmpl->addVar("_widget", "code", $this->convertToDispString($logMsgCode));
 		$this->tmpl->addVar("_widget", "access_log_serial", $accessLog);
 		$this->tmpl->addVar("_widget", "time", $time);
 		
