@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTestWidgetContainer.php 4253 2011-08-21 11:12:00Z fishbone $
+ * @version    SVN: $Id: admin_mainTestWidgetContainer.php 4466 2011-11-25 02:25:22Z fishbone $
  * @link       http://www.magic3.org
  */
 //require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -62,12 +62,19 @@ class admin_mainTestWidgetContainer extends admin_mainBaseWidgetContainer
 //		exec('ls', $output, $retValue);
 //		echo '*****='.$retValue;
 		
-		exec('cd /var/www/html/magic3/;/var/www/html/magic3/run_jtalk.sh', $output, $retValue);
-		echo '*****='.$retValue;
-		var_dump($output);
+//		exec('cd /var/www/html/magic3/;/var/www/html/magic3/run_jtalk.sh', $output, $retValue);
+//		echo '*****='.$retValue;
+//		var_dump($output);
 		
 //		passthru('cd /var/www/html/magic3/;/var/www/html/magic3/run_jtalk.sh',$retValue);
 //		echo '*****='.$retValue;
+
+		echo intval(strStartsWith("im", 'img'));
+		echo intval(strStartsWith("img", 'img'));
+		echo intval(strStartsWith("img.jpg", 'img'));
+		
+		echo intval(strEndsWith("img", '.jpg'));
+		echo intval(strEndsWith("img.jpg", '.jpg'));
 	/*
 				// ページ作成処理中断
 				$this->gPage->abortPage();
