@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetContainer.php 4295 2011-09-06 02:46:39Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetContainer.php 4466 2011-11-25 02:25:22Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -151,6 +151,8 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 						$task = 'pageinfo';			// ページ情報をデフォルトにする
 					} else if ($task == 'userlist_detail'){		// ユーザ詳細
 						$task = 'userlist';
+					} else if ($task == 'usergroup_detail'){		// ユーザグループ詳細
+						$task = 'usergroup';
 					} else if ($task == 'loginstatus' ||				// ログイン状況
 								$task == 'loginstatus_history'){		// ログイン状況ユーザ単位履歴
 						$task = 'loginstatus';
@@ -213,6 +215,7 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 						case 'test';			// テスト用画面
 						case 'top';			// トップ画面
 						case 'userlist':	// ユーザリスト
+						case 'usergroup':	// ユーザグループ
 						case 'loginstatus':	// ログイン状況
 						case 'widgetlist':	// ウィジェットリスト
 						case 'templist':	// テンプレートリスト
