@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainEntryWidgetContainer.php 3666 2010-10-04 07:36:04Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainEntryWidgetContainer.php 4063 2011-04-08 08:47:16Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_blog_mainBaseWidgetContainer.php');
@@ -175,6 +175,18 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 				}
 			}
 			if (count($delItems) > 0){
+				// 削除するブログ記事の情報を取得
+				$delEntryInfo = array();
+				for ($i = 0; $i < count($delItems); $i++){
+					$ret = $this->db->getEntryBySerial($delItems[$i], $row, $categoryRow);
+					if ($ret){
+						$newInfoObj = new stdClass;
+						$newInfoObj->entryId = $row['be_id'];		// 記事ID
+						$newInfoObj->name = $row['be_name'];		// 記事タイトル
+						$delEntryInfo[] = $newInfoObj;
+					}
+				}
+				
 				$ret = $this->db->delEntryItem($delItems);
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
@@ -186,6 +198,12 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					
 					// 親ウィンドウを更新
 					$this->gPage->updateParentWindow();
+					
+					// 運用ログを残す
+					for ($i = 0; $i < count($delEntryInfo); $i++){
+						$infoObj = $delEntryInfo[$i];
+						$this->gOpeLog->writeUserInfo(__METHOD__, 'ブログ記事を削除しました。ID: ' . $infoObj->entryId, 2100, 'タイトル=' . $infoObj->name);
+					}
 				} else {
 					$this->setAppErrorMsg('データ削除に失敗しました');
 				}
@@ -375,6 +393,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 				}
 				if ($ret){
 					$this->setGuidanceMsg('データを追加しました');
+					
 					// シリアル番号更新
 					$this->serialNo = $newSerial;
 					$dataReload = true;		// データの再ロード
@@ -384,6 +403,22 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					
 					// 親ウィンドウを更新
 					$this->gPage->updateParentWindow();
+					
+					// 運用ログを残す
+					$statusStr = '';
+					$ret = $this->db->getEntryBySerial($this->serialNo, $row, $categoryRow);
+					if ($ret){
+						$this->entryId = $row['be_id'];		// 記事ID
+						$name = $row['be_name'];		// コンテンツ名前
+						
+						// 公開状態
+						switch ($row['be_status']){
+							case 1:	$statusStr = '編集中';	break;
+							case 2:	$statusStr = '公開';	break;
+							case 3:	$statusStr = '非公開';	break;
+						}
+					}
+					$this->gOpeLog->writeUserInfo(__METHOD__, 'ブログ記事を追加(' . $statusStr . ')しました。ID: ' . $this->entryId, 2100, 'タイトル=' . $name);
 				} else {
 					$this->setAppErrorMsg('データ追加に失敗しました');
 				}
@@ -427,6 +462,22 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					
 					// 親ウィンドウを更新
 					$this->gPage->updateParentWindow();
+					
+					// 運用ログを残す
+					$statusStr = '';
+					$ret = $this->db->getEntryBySerial($this->serialNo, $row, $categoryRow);
+					if ($ret){
+						$this->entryId = $row['be_id'];		// 記事ID
+						$name = $row['be_name'];		// コンテンツ名前
+						
+						// 公開状態
+						switch ($row['be_status']){
+							case 1:	$statusStr = '編集中';	break;
+							case 2:	$statusStr = '公開';	break;
+							case 3:	$statusStr = '非公開';	break;
+						}
+					}
+					$this->gOpeLog->writeUserInfo(__METHOD__, 'ブログ記事を更新(' . $statusStr . ')しました。ID: ' . $this->entryId, 2100, 'タイトル=' . $name);
 				} else {
 					$this->setAppErrorMsg('データ更新に失敗しました');
 				}
@@ -437,6 +488,13 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			}
 			// エラーなしの場合は、データを削除
 			if ($this->getMsgCount() == 0){
+				// 削除するブログ記事の情報を取得
+				$ret = $this->db->getEntryBySerial($this->serialNo, $row, $categoryRow);
+				if ($ret){
+					$this->entryId = $row['be_id'];		// 記事ID
+					$name = $row['be_name'];		// コンテンツ名前
+				}
+					
 				$ret = $this->db->delEntryItem(array($this->serialNo));
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
@@ -446,6 +504,9 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					
 					// 親ウィンドウを更新
 					$this->gPage->updateParentWindow();
+					
+					// 運用ログを残す
+					$this->gOpeLog->writeUserInfo(__METHOD__, 'ブログ記事を削除しました。ID: ' . $this->entryId, 2100, 'タイトル=' . $name);
 				} else {
 					$this->setAppErrorMsg('データ削除に失敗しました');
 				}
@@ -456,6 +517,13 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			}
 			// エラーなしの場合は、データを削除
 			if ($this->getMsgCount() == 0){
+				// 削除するブログ記事の情報を取得
+				$ret = $this->db->getEntryBySerial($this->serialNo, $row, $categoryRow);
+				if ($ret){
+					$this->entryId = $row['be_id'];		// 記事ID
+					$name = $row['be_name'];		// コンテンツ名前
+				}
+				
 				$ret = $this->db->delEntryItemById($this->serialNo);
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
@@ -465,6 +533,9 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					
 					// 親ウィンドウを更新
 					$this->gPage->updateParentWindow();
+					
+					// 運用ログを残す
+					$this->gOpeLog->writeUserInfo(__METHOD__, 'ブログ記事を削除しました。ID: ' . $this->entryId, 2100, 'タイトル=' . $name);
 				} else {
 					$this->setAppErrorMsg('データ削除に失敗しました');
 				}
