@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentWidgetContainer.php 2933 2010-03-17 14:19:35Z fishbone $
+ * @version    SVN: $Id: admin_default_contentWidgetContainer.php 4050 2011-03-27 06:10:11Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_default_contentBaseWidgetContainer.php');
@@ -44,13 +44,14 @@ class admin_default_contentWidgetContainer extends admin_default_contentBaseWidg
 		// コンテナを起動
 		$goWidget = false;		// サブウィジェットを実行するかどうか
 		switch ($task){
-			case 'content':		// コンテンツ管理
-			case 'content_detail':		// コンテンツ管理(詳細)
-			case 'add_to_menu':	// コンテンツへのリンクをメニューに追加
-				$task = 'content';
+			case self::TASK_CONTENT:		// コンテンツ管理
+			case self::TASK_CONTENT_DETAIL:		// コンテンツ管理(詳細)
+			case self::TASK_ADD_TO_MENU:	// コンテンツへのリンクをメニューに追加
+				$task = self::TASK_CONTENT;
 				$goWidget = true;		// サブウィジェットを実行するかどうか
 				break;
-			case 'other':		// その他設定
+			case self::TASK_HISTORY:	// コンテンツ履歴
+			case self::TASK_OTHER:		// その他設定
 				$goWidget = true;		// サブウィジェットを実行するかどうか
 				break;
 			default:
