@@ -8,17 +8,15 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_m_custom_footerWidgetContainer.php 868 2008-07-28 12:13:33Z fishbone $
+ * @version    SVN: $Id: admin_m_custom_footerWidgetContainer.php 2271 2009-08-31 07:00:18Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
 
-class admin_m_custom_footerWidgetContainer extends BaseWidgetContainer
+class admin_m_custom_footerWidgetContainer extends BaseAdminWidgetContainer
 {
-	const IMAGE_DIR = 'images';				// 画像ディレクトリ名
-	
 	/**
 	 * コンストラクタ
 	 */
@@ -52,9 +50,6 @@ class admin_m_custom_footerWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gPageManager;
-
 		$act = $request->trimValueOf('act');
 		if ($act == 'update'){		// 設定更新のとき
 			// 入力値を取得
@@ -69,10 +64,11 @@ class admin_m_custom_footerWidgetContainer extends BaseWidgetContainer
 					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
 				}				
 			}
-			$gPageManager->updateParentWindow();// 親ウィンドウを更新
+			$this->gPage->updateParentWindow();// 親ウィンドウを更新
 		} else {		// 初期表示の場合
 			// デフォルト値設定
 			$footContent = '';	// フッタコンテンツ
+			$footContent .= '<hr />' . M3_NL;
 			$footContent .= '<div align="center">(C) ' . date("Y") . ' Magic3.org</div>' . M3_NL;
 			$footContent .= '<div align="center"><a href="http://www.magic3.org">Magic3 ' . M3_SYSTEM_VERSION . '</a> is licensed under the terms of the GNU General Public License.</div>' . M3_NL;
 			$paramObj = $this->getWidgetParamObj();
@@ -83,11 +79,6 @@ class admin_m_custom_footerWidgetContainer extends BaseWidgetContainer
 		
 		// 画面にデータを埋め込む
 		$this->tmpl->addVar("_widget", "content",	$footContent);
-		
-		// パスの設定
-		$this->tmpl->addVar("_widget", "widget_url", $gEnvManager->getCurrentWidgetRootUrl());	// ウィジェットのルートディレクトリ
-		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
-		$this->tmpl->addVar("_widget", "widget_sc_url", $gEnvManager->getCurrentWidgetScriptsUrl());
 	}
 }
 ?>
