@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainCommonDef.php 4384 2011-10-07 12:29:54Z fishbone $
+ * @version    SVN: $Id: photo_mainCommonDef.php 4393 2011-10-13 13:07:12Z fishbone $
  * @link       http://www.magic3.org
  */
  
@@ -34,6 +34,7 @@ class photo_mainCommonDef
 	const SEARCH_SORT_ID = 'photo_main_sort';
 	const SEARCH_FORM_ID = 'photo_main_form';
 	const USER_OPTION = ';photo_main=author;';		// ログインユーザのユーザオプション
+	const EC_LIB_OBJ_ID = 'eclib';		// Eコマースオブジェクト
 	
 	// DB定義値
 	const CF_THUMBNAIL_BG_COLOR			= 'thumbnail_bg_color';		// サムネール背景色
@@ -42,6 +43,7 @@ class photo_mainCommonDef
 	const CF_PHOTO_LIST_ORDER			= 'photo_list_order';			// 画像一覧並び順
 	const CF_PHOTO_TITLE_SHORT_LENGTH	= 'photo_title_short_length';// 略式写真タイトルの長さ
 	const CF_IMAGE_PROTECT_COPYRIGHT	= 'image_protect_copyright';		// 画像著作権保護
+	const CF_ONLINE_SHOP				= 'online_shop';			// オンラインショップ機能
 	
 	/**
 	 * サムネール画像のパスを取得
@@ -106,7 +108,7 @@ class photo_mainCommonDef
 		// ページ作成処理中断
 		$gPageManager->abortPage();
 
-		$ret = $db->getPhotoInfo($photoId, $row);
+		$ret = $db->getPhotoInfo($photoId, $gEnvManager->getCurrentLanguage(), $row);
 		if ($ret){
 			header('Content-type: ' . $row['ht_mime_type']);// 画像タイプ
 			// キャッシュの設定
