@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainTopWidgetContainer.php 4411 2011-10-20 04:23:14Z fishbone $
+ * @version    SVN: $Id: photo_mainTopWidgetContainer.php 4455 2011-11-15 08:23:01Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/photo_mainBaseWidgetContainer.php');
@@ -188,6 +188,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		
 		// POST,GET値取得
 		$keyword = $request->trimValueOf(M3_REQUEST_PARAM_KEYWORD);		// 検索キーワード
+		$paramPageNo = $request->trimValueOf(M3_REQUEST_PARAM_PAGE_NO);		// ページ番号パラメータ
 		$pageNo = $request->trimIntValueOf(M3_REQUEST_PARAM_PAGE_NO, '1');				// ページ番号
 		$category = $request->trimValueOf('category');		// カテゴリー
 		$author = $request->trimValueOf('author');			// 著作者
@@ -199,8 +200,18 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		// URLパラメータ作成
 		$urlParams = $this->createUrlParams($keyword, $category, $author, $sort);
 		
+		// キーワード分割
+		$parsedKeywords = $this->gInstance->getTextConvManager()->parseSearchKeyword($keyword);
+
+		// ##### 検索キーワードを記録 #####
+		if (empty($paramPageNo)){			// 検索を実行した時点のみ記録
+			for ($i = 0; $i < count($parsedKeywords); $i++){
+				$this->gInstance->getAnalyzeManager()->logSearchWord($this->gEnv->getCurrentWidgetId(), $parsedKeywords[$i]);
+			}
+		}
+				
 		// 写真数を取得
-		$totalCount = self::$_mainDb->searchPhotoItemCount($this->_langId, null/*開始日時*/, null/*終了日時*/, $keyword/*キーワード*/,
+		$totalCount = self::$_mainDb->searchPhotoItemCount($this->_langId, null/*開始日時*/, null/*終了日時*/, $parsedKeywords/*キーワード*/,
 															$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/);
 		
 		// リンク文字列作成、ページ番号調整
@@ -284,10 +295,13 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		// URLパラメータ作成
 		$urlParams = $this->createUrlParams($keyword, $category, $author, $sort);
 		
+		// キーワード分割
+		$parsedKeywords = $this->gInstance->getTextConvManager()->parseSearchKeyword($keyword);
+		
 		// デフォルトでは最新の登録画像を取得
 		$this->photoArray = array();	// 取得した写真
 		$this->startNo = $this->viewCount * ($pageNo -1) + 1;
-		self::$_mainDb->searchPhotoItem($this->viewCount, $pageNo, $this->_langId, null/*開始日時*/, null/*終了日時*/, $keyword/*キーワード*/,
+		self::$_mainDb->searchPhotoItem($this->viewCount, $pageNo, $this->_langId, null/*開始日時*/, null/*終了日時*/, $parsedKeywords/*キーワード*/,
 						$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/, $this->sortKey/*ソートキー*/, $this->sortDirection/*ソート方向*/, array($this, 'viewListLoop'), $urlParams);
 
 		// Ajax戻りデータ
@@ -322,6 +336,9 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			// URLパラメータ作成
 			$urlParams = $this->createUrlParams($keyword, $category, $author, $sort);
 			
+			// キーワード分割
+			$parsedKeywords = $this->gInstance->getTextConvManager()->parseSearchKeyword($keyword);
+		
 			// ページ番号修正
 			$pageNo = intval(($itemNo -1) / $this->viewCount) + 1;
 		
@@ -357,7 +374,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			
 			// 前後のリンクを取得
 			$this->startNo = $request->trimIntValueOf(M3_REQUEST_PARAM_ITEM_NO, '1');
-			self::$_mainDb->searchPhotoItemByNo(3, $this->startNo -1, $this->_langId, null/*開始日時*/, null/*終了日時*/, $keyword/*キーワード*/, 
+			self::$_mainDb->searchPhotoItemByNo(3, $this->startNo -1, $this->_langId, null/*開始日時*/, null/*終了日時*/, $parsedKeywords/*キーワード*/, 
 					$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/, $this->sortKey/*ソートキー*/, $this->sortDirection/*ソート方向*/, array($this, 'prevNextListLoop'), $urlParams);
 		
 			// 戻り先一覧画面のURLを取得
