@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainDb.php 4415 2011-10-23 13:45:18Z fishbone $
+ * @version    SVN: $Id: photo_mainDb.php 4455 2011-11-15 08:23:01Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -531,7 +531,7 @@ class photo_mainDb extends BaseDb
 	 * @param string	$langId				言語
 	 * @param timestamp	$startDt			期間(開始日)
 	 * @param timestamp	$endDt				期間(終了日)
-	 * @param string	$keyword			検索キーワード
+	 * @param array		$keywords			検索キーワード
 	 * @param array		$category			カテゴリーID
 	 * @param array		$author				撮影者
 	 * @param string	$sortKey			ソートキー(date=日付,rate=評価,ref=参照数)
@@ -540,7 +540,7 @@ class photo_mainDb extends BaseDb
 	 * @param string    $urlOthers			URL付加パラメータ
 	 * @return 			なし
 	 */
-	function searchPhotoItem($limit, $page, $langId, $startDt, $endDt, $keyword, $category, $author, $sortKey, $sortDirection, $callback, $urlOthers)
+	function searchPhotoItem($limit, $page, $langId, $startDt, $endDt, $keywords, $category, $author, $sortKey, $sortDirection, $callback, $urlOthers)
 	{
 		$offset = $limit * ($page -1);
 		if ($offset < 0) $offset = 0;
@@ -571,16 +571,17 @@ class photo_mainDb extends BaseDb
 			$queryStr .=  'AND hw_category_id in (' . $idStr . ') ';
 		}
 		// キーワード検索
-		if (!empty($keyword)){
-			// 「'"\」文字をエスケープ
-			$keyword = addslashes($keyword);
-			$queryStr .=    'AND (ht_public_id LIKE \'%' . $keyword . '%\' ';		// 公開用画像ID
-			$queryStr .=    'OR ht_name LIKE \'%' . $keyword . '%\' ';		// 画像タイトル
-			$queryStr .=    'OR ht_camera LIKE \'%' . $keyword . '%\' ';		// カメラ
-			$queryStr .=    'OR ht_location LIKE \'%' . $keyword . '%\' ';		// 撮影場所
-			$queryStr .=    'OR ht_note LIKE \'%' . $keyword . '%\' ';		// メモ
-			$queryStr .=    'OR ht_keyword LIKE \'%' . $keyword . '%\' ';		// キーワード
-			$queryStr .=    'OR lu_name LIKE \'%' . $keyword . '%\') ';	// 撮影者
+		if (!empty($keywords)){
+			for ($i = 0; $i < count($keywords); $i++){
+				$keyword = addslashes($keywords[$i]);// 「'"\」文字をエスケープ
+				$queryStr .=    'AND (ht_public_id LIKE \'%' . $keyword . '%\' ';		// 公開用画像ID
+				$queryStr .=    'OR ht_name LIKE \'%' . $keyword . '%\' ';		// 画像タイトル
+				$queryStr .=    'OR ht_camera LIKE \'%' . $keyword . '%\' ';		// カメラ
+				$queryStr .=    'OR ht_location LIKE \'%' . $keyword . '%\' ';		// 撮影場所
+				$queryStr .=    'OR ht_note LIKE \'%' . $keyword . '%\' ';		// メモ
+				$queryStr .=    'OR ht_keyword LIKE \'%' . $keyword . '%\' ';		// キーワード
+				$queryStr .=    'OR lu_name LIKE \'%' . $keyword . '%\') ';	// 撮影者
+			}
 		}
 		// 撮影者
 		if (!empty($author)){
@@ -617,7 +618,7 @@ class photo_mainDb extends BaseDb
 	 * @param string	$langId				言語
 	 * @param timestamp	$startDt			期間(開始日)
 	 * @param timestamp	$endDt				期間(終了日)
-	 * @param string	$keyword			検索キーワード
+	 * @param array		$keywords			検索キーワード
 	 * @param array		$category			カテゴリーID
 	 * @param array		$author				撮影者
 	 * @param string	$sortKey			ソートキー(date=日付,rate=評価,ref=参照数)
@@ -626,7 +627,7 @@ class photo_mainDb extends BaseDb
 	 * @param string    $urlOthers			URL付加パラメータ
 	 * @return 			なし
 	 */
-	function searchPhotoItemByNo($limit, $no, $langId, $startDt, $endDt, $keyword, $category, $author, $sortKey, $sortDirection, $callback, $urlOthers)
+	function searchPhotoItemByNo($limit, $no, $langId, $startDt, $endDt, $keywords, $category, $author, $sortKey, $sortDirection, $callback, $urlOthers)
 	{
 		$offset = $no -1;
 		if ($offset < 0) $offset = 0;
@@ -657,16 +658,17 @@ class photo_mainDb extends BaseDb
 			$queryStr .=  'AND hw_category_id in (' . $idStr . ') ';
 		}
 		// キーワード検索
-		if (!empty($keyword)){
-			// 「'"\」文字をエスケープ
-			$keyword = addslashes($keyword);
-			$queryStr .=    'AND (ht_public_id LIKE \'%' . $keyword . '%\' ';		// 公開用画像ID
-			$queryStr .=    'OR ht_name LIKE \'%' . $keyword . '%\' ';		// 画像タイトル
-			$queryStr .=    'OR ht_camera LIKE \'%' . $keyword . '%\' ';		// カメラ
-			$queryStr .=    'OR ht_location LIKE \'%' . $keyword . '%\' ';		// 撮影場所
-			$queryStr .=    'OR ht_note LIKE \'%' . $keyword . '%\' ';		// メモ
-			$queryStr .=    'OR ht_keyword LIKE \'%' . $keyword . '%\' ';		// キーワード
-			$queryStr .=    'OR lu_name LIKE \'%' . $keyword . '%\') ';	// 撮影者
+		if (!empty($keywords)){
+			for ($i = 0; $i < count($keywords); $i++){
+				$keyword = addslashes($keywords[$i]);// 「'"\」文字をエスケープ
+				$queryStr .=    'AND (ht_public_id LIKE \'%' . $keyword . '%\' ';		// 公開用画像ID
+				$queryStr .=    'OR ht_name LIKE \'%' . $keyword . '%\' ';		// 画像タイトル
+				$queryStr .=    'OR ht_camera LIKE \'%' . $keyword . '%\' ';		// カメラ
+				$queryStr .=    'OR ht_location LIKE \'%' . $keyword . '%\' ';		// 撮影場所
+				$queryStr .=    'OR ht_note LIKE \'%' . $keyword . '%\' ';		// メモ
+				$queryStr .=    'OR ht_keyword LIKE \'%' . $keyword . '%\' ';		// キーワード
+				$queryStr .=    'OR lu_name LIKE \'%' . $keyword . '%\') ';	// 撮影者
+			}
 		}
 		// 撮影者
 		if (!empty($author)){
@@ -701,12 +703,12 @@ class photo_mainDb extends BaseDb
 	 * @param string	$langId				言語
 	 * @param timestamp	$startDt			期間(開始日)
 	 * @param timestamp	$endDt				期間(終了日)
-	 * @param string	$keyword			検索キーワード
+	 * @param array		$keywords			検索キーワード
 	 * @param array		$category			カテゴリーID
 	 * @param array		$author				撮影者
 	 * @return 			なし
 	 */
-	function searchPhotoItemCount($langId, $startDt, $endDt, $keyword, $category, $author)
+	function searchPhotoItemCount($langId, $startDt, $endDt, $keywords, $category, $author)
 	{
 		// 日付範囲
 		/*
@@ -734,16 +736,17 @@ class photo_mainDb extends BaseDb
 			$queryStr .=  'AND hw_category_id in (' . $idStr . ') ';
 		}
 		// キーワード検索
-		if (!empty($keyword)){
-			// 「'"\」文字をエスケープ
-			$keyword = addslashes($keyword);
-			$queryStr .=    'AND (ht_public_id LIKE \'%' . $keyword . '%\' ';		// 公開用画像ID
-			$queryStr .=    'OR ht_name LIKE \'%' . $keyword . '%\' ';		// 画像タイトル
-			$queryStr .=    'OR ht_camera LIKE \'%' . $keyword . '%\' ';		// カメラ
-			$queryStr .=    'OR ht_location LIKE \'%' . $keyword . '%\' ';		// 撮影場所
-			$queryStr .=    'OR ht_note LIKE \'%' . $keyword . '%\' ';		// メモ
-			$queryStr .=    'OR ht_keyword LIKE \'%' . $keyword . '%\' ';		// キーワード
-			$queryStr .=    'OR lu_name LIKE \'%' . $keyword . '%\') ';	// 撮影者
+		if (!empty($keywords)){
+			for ($i = 0; $i < count($keywords); $i++){
+				$keyword = addslashes($keywords[$i]);		// 「'"\」文字をエスケープ
+				$queryStr .=    'AND (ht_public_id LIKE \'%' . $keyword . '%\' ';		// 公開用画像ID
+				$queryStr .=    'OR ht_name LIKE \'%' . $keyword . '%\' ';		// 画像タイトル
+				$queryStr .=    'OR ht_camera LIKE \'%' . $keyword . '%\' ';		// カメラ
+				$queryStr .=    'OR ht_location LIKE \'%' . $keyword . '%\' ';		// 撮影場所
+				$queryStr .=    'OR ht_note LIKE \'%' . $keyword . '%\' ';		// メモ
+				$queryStr .=    'OR ht_keyword LIKE \'%' . $keyword . '%\' ';		// キーワード
+				$queryStr .=    'OR lu_name LIKE \'%' . $keyword . '%\') ';	// 撮影者
+			}
 		}
 		// 撮影者
 		if (!empty($author)){
