@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_user_contentBaseWidgetContainer.php 3421 2010-07-23 06:08:01Z fishbone $
+ * @version    SVN: $Id: admin_user_contentBaseWidgetContainer.php 3655 2010-10-01 07:16:39Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -21,7 +21,7 @@ class admin_user_contentBaseWidgetContainer extends BaseAdminWidgetContainer
 	protected $_localDb;			// DB接続オブジェクト
 	protected $_itemTypeArray;		// コンテンツ項目のデータタイプ
 	const DEFAULT_TOP_PAGE = 'content';		// デフォルトのトップページ
-	const WIDGET_TITLE_NAME = 'ユーザ作成コンテンツ';				// ウィジェットタイトル名
+	const WIDGET_TITLE_NAME = 'ユーザコンテンツ';				// ウィジェットタイトル名
 	
 	/**
 	 * コンストラクタ
